startBackgroundPollingService method
Start a standalone background poller process that keeps polling pollingUrl
and showing toasts even after the app is fully closed (Windows only).
Implementation
@override
Future<bool> startBackgroundPollingService({
required String pollingUrl,
int? intervalMinutes,
}) async {
final result = await methodChannel.invokeMethod<bool>(
'startBackgroundPollingService',
{'pollingUrl': pollingUrl, 'intervalMinutes': intervalMinutes},
);
return result ?? false;
}