NotificationMasterPlatform class
abstract
- Inheritance
-
- Object
- PlatformInterface
- NotificationMasterPlatform
- Implementers
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
checkNotificationPermission()
→ Future<bool>
-
-
createCustomChannel({required String channelId, required String channelName, String? channelDescription, int? importance, bool? enableLights, int? lightColor, bool? enableVibration, bool? enableSound})
→ Future<bool>
-
-
getActiveNotificationService()
→ Future<String>
-
-
getPlatformVersion()
→ Future<String?>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
requestNotificationPermission()
→ Future<bool>
-
-
setFirebaseAsActiveService()
→ Future<bool>
-
-
showBigTextNotification({required String title, required String message, required String bigText, String? channelId, NotificationImportance? importance, bool? autoCancel, String? targetScreen, })
→ Future<int>
-
-
showFullScreenNotification({required String title, required String message, String? targetScreen, })
→ Future<int>
-
-
showHeadsUpNotification({required String title, required String message, String? targetScreen, })
→ Future<int>
-
-
showImageNotification({required String title, required String message, required String imageUrl, String? channelId, NotificationImportance? importance, bool? autoCancel, String? targetScreen, })
→ Future<int>
-
-
showNotification({int? id, required String title, required String message, String? channelId, NotificationImportance? importance, bool? autoCancel, String? targetScreen, })
→ Future<int>
-
-
showNotificationWithActions({required String title, required String message, required List<Map<String, String>> actions, String? channelId, NotificationImportance? importance, bool? autoCancel, String? targetScreen, })
→ Future<int>
-
-
showStyledNotification({required String title, required String message, String? channelId, String? targetScreen, })
→ Future<int>
-
-
startForegroundService({required String pollingUrl, int? intervalMinutes, String? channelId})
→ Future<bool>
-
-
startNotificationPolling({required String pollingUrl, int? intervalMinutes})
→ Future<bool>
-
-
stopForegroundService()
→ Future<bool>
-
-
stopNotificationPolling()
→ Future<bool>
-
-
toString()
→ String
-
A string representation of this object.
inherited