getPendingScheduledNotifications method
Returns the ids of notifications that are scheduled but not yet delivered.
Implementation
@override
Future<List<int>> getPendingScheduledNotifications() async {
return _scheduledTimers.keys.toList();
}
Returns the ids of notifications that are scheduled but not yet delivered.
@override
Future<List<int>> getPendingScheduledNotifications() async {
return _scheduledTimers.keys.toList();
}