MethodChannelNotificationMaster class

An implementation of NotificationMasterPlatform that uses method channels.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkNotificationPermission() Future<bool>
override
createCustomChannel({required String channelId, required String channelName, String? channelDescription, int? importance, bool? enableLights, int? lightColor, bool? enableVibration, bool? enableSound}) Future<bool>
override
getActiveNotificationService() Future<String>
override
getPlatformVersion() Future<String?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestNotificationPermission() Future<bool>
override
setFirebaseAsActiveService() Future<bool>
override
showBigTextNotification({required String title, required String message, required String bigText, String? channelId, NotificationImportance? importance, bool? autoCancel, String? targetScreen, Map<String, dynamic>? extraData}) Future<int>
override
showFullScreenNotification({required String title, required String message, String? targetScreen, Map<String, dynamic>? extraData}) Future<int>
override
showHeadsUpNotification({required String title, required String message, String? targetScreen, Map<String, dynamic>? extraData}) Future<int>
override
showImageNotification({required String title, required String message, required String imageUrl, String? channelId, NotificationImportance? importance, bool? autoCancel, String? targetScreen, Map<String, dynamic>? extraData}) Future<int>
override
showNotification({int? id, required String title, required String message, String? channelId, NotificationImportance? importance, bool? autoCancel, String? targetScreen, Map<String, dynamic>? extraData}) Future<int>
override
showNotificationWithActions({required String title, required String message, required List<Map<String, String>> actions, String? channelId, NotificationImportance? importance, bool? autoCancel, String? targetScreen, Map<String, dynamic>? extraData}) Future<int>
override
showStyledNotification({required String title, required String message, String? channelId, String? targetScreen, Map<String, dynamic>? extraData}) Future<int>
override
startForegroundService({required String pollingUrl, int? intervalMinutes, String? channelId}) Future<bool>
override
startNotificationPolling({required String pollingUrl, int? intervalMinutes}) Future<bool>
override
stopForegroundService() Future<bool>
override
stopNotificationPolling() Future<bool>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited