scheduleNotification method
Schedule a notification to be delivered by the operating system at a specific point in time, even when the app is fully closed.
Implementation
Future<bool> scheduleNotification({
required int id,
required String title,
required String message,
required int scheduledEpochMillis,
String? channelId,
NotificationImportance? importance,
bool alarmSound = false,
String? targetScreen,
Map<String, dynamic>? extraData,
}) {
throw UnimplementedError(
'scheduleNotification() has not been implemented.',
);
}