startBackgroundPollingService method
Start a standalone background poller process that keeps polling pollingUrl
and showing toasts even after the app is fully closed (Windows only).
Implementation
Future<bool> startBackgroundPollingService({
required String pollingUrl,
int? intervalMinutes,
}) {
throw UnimplementedError(
'startBackgroundPollingService() has not been implemented.',
);
}