startBackgroundPollingService method
Start a standalone background poller process that keeps polling pollingUrl
and showing toasts even after the app is fully closed (Windows only).
Implementation
@override
Future<bool> startBackgroundPollingService({
required String pollingUrl,
int? intervalMinutes,
}) async {
throw UnsupportedError(
'startBackgroundPollingService is only available on Windows. '
'Background polling is not supported in the browser.',
);
}